Description Usage Arguments Author(s) Examples
Retrieve all publications related to user-defined search query from PubMed database
1 2 3 4 5 6 | Get.Publication.info(
Searchquery,
Publicationinfo = c("title", "source", "lastauthor", "pubtype", "pubdate",
"pmcrefcount"),
Output = NULL
)
|
Searchquery |
input a text query for example "Bioinformatics", "Bioinformatics or machine learning", "Cancer and drug targets" |
Publicationinfo |
information to be returned from pubmed such paper title, last author, journal or number of citations |
Output |
path to save file containig results returened by the function. |
Mohmed Soudy Mohamed.soudy@57357.com and Ali Mostafa ali.mo.anwar@std.agr.cu.edu.eg
1 | Publications <- Get.Publication.info(Searchquery = "physics and deep learning and proteomics")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.