Plot.TopJournals: Plot Top cited Journals from data returned by...

Description Usage Arguments Author(s)

View source: R/PlotPublications.R

Description

Plot Top cited Journals from data returned by "Get.Publication.info" Function

Usage

1
Plot.TopJournals(Publications, Top = 10, directorypath  = NULL)

Arguments

Publications

Dataframe returned by "Get.Publication.info" Function.

Top

Number of Journals to be visulaized sorted by citations.

directorypath

path to save plot generated by the function.

Author(s)

Mohmed Soudy Mohamed.soudy@57357.com and Ali Mostafa ali.mo.anwar@std.agr.cu.edu.eg


ResearchAssociate documentation built on Jan. 13, 2021, 4:04 p.m.