Description Usage Arguments Author(s)
View source: R/PlotPublications.R
Plot Top cited publications from data returned by "Get.Publication.info" Function
1 | Plot.TopPapers(Publications, Top = 10, directorypath = NULL)
|
Publications |
Dataframe returned by "Get.Publication.info" Function. |
Top |
Number of publications to be visulaized sorted by citations. |
directorypath |
path to save plot generated by the function. |
Mohmed Soudy Mohamed.soudy@57357.com and Ali Mostafa ali.mo.anwar@std.agr.cu.edu.eg
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.